import * as core from "@actions/core";
import { exec } from "@actions/exec";
import * as github from "@actions/github";

import { GITHUB_TOKEN, OPAM_DEPEXT } from "./constants.js";

const {
  repo: { owner, repo },
  runId: run_id,
} = github.context;

export async function installDune() {
  await core.group("Install dune", async () => {
    if (OPAM_DEPEXT) {
      await exec("opam", ["depext", "--install", "dune"]);
    } else {
      await exec("opam", ["install", "dune"]);
    }
  });
}

export async function trimDuneCache() {
  await core.group(
    "Remove oldest files from the dune cache to free space",
    async () => {
      const octokit = github.getOctokit(GITHUB_TOKEN);
      const {
        data: { total_count: totalCount },
      } = await octokit.rest.actions.listJobsForWorkflowRun({
        owner,
        repo,
        run_id,
      });
      const cacheSize = Math.floor(5000 / totalCount);
      await exec("opam", [
        "exec",
        "--",
        "dune",
        "cache",
        "trim",
        "--size",
        `${cacheSize}MB`,
      ]);
    },
  );
}
